<?php 
namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;

/**
 * @ControlPlugin(
 *   id = "checkbox",
 *   label = @Translation("Checkbox")
 * )
 */


class ControlCheckbox extends ControlBase {

	public function get_type() {
		return 'checkbox';
	}

	public function content_template(array $params = []) {
		
		$data = $params['data'] ?? null;
    	$name = $params['name'] ?? null;
    	$value = $params['value'] ?? null;
		$attributes = '';
		$class = 'form-check-input';
		$extra_class = [];
		$data_value = $data['item']['value'];


		$selector = !empty($data['item']['update_selector']) ? 'data-update-selector="#widget-id-' . $data['wid'] . ' ' . $data['item']['update_selector'] . '"' : null;
	
		if (isset($data['delta']) && strpos($selector, '[index]') !== false) {
			$selector = str_replace('[index]', $data['delta'], $selector);
		}
		
		if (!empty($data['item']['attributes'])) {
			$attributes = implode(' ', array_map(
				function ($key, $value) {
					return sprintf('%s="%s"', $key, htmlspecialchars($value));
				},
				array_keys($data['item']['attributes']),
				$data['item']['attributes']
			));
		
			if (!empty($data['item']['attributes']['class'])) {
				$extra_class = $data['item']['attributes']['class'];
			}
		

		}

		$class = $class . ' ' . implode(' ', (array) $extra_class);
		
		// $class = implode(" ", $class);
		$checked = ($value == $data_value) ? 'checked' : '';
		$selectorAttr = $selector ?? '';
		
		$html = '<div class="form-check form-switch">';
		$html .= '<input type="checkbox" ';
		$html .= 'id="option-' . $data['item_id'] . '" ';
		$html .= 'name="' . htmlspecialchars($name) . '" ';
		$html .= 'value="' . htmlspecialchars($data_value) . '" ';

		$html .= $checked . ' ';
		$html .= 'class="' . $class . '" ';
		$html .= $selectorAttr . ' ';
		$html .= 'field-settings>';
		$html .= '<label for="option-' . $data['item_id'] . '" class="form-check-label">';
		$html .= htmlspecialchars($data['item']['title']);
		$html .= '</label></div>';
		
		return $html;
	}
	
	public function render_control($data){
		return $this->base($data, $this->content_template($data));
	}
	
	public function get_default_settings() {
		return [
			'input_type' => 'checkbox',
			'title' => '',
		];
	}
}

